Cvar

Struct Cvar 

pub struct Cvar<'a> {
    data: FontData<'a>,
}
The cvar table.

Fields

data: FontData<'a>

Implementations

Source

impl<'a> Cvar<'a>

pub const MIN_SIZE: usize

pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>

Resolve the provided offset from the start of this table.

pub fn offset_data(&self) -> FontData<'a>

Return a reference to this table’s raw data.

We use this in the compile crate to resolve offsets.

pub fn shape(&self) -> &Self

👎Deprecated: just use the base type directly

Return a reference to the table’s ‘Shape’ struct.

This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.

pub fn version(&self) -> MajorMinor

Major/minor version number of the CVT variations table — set to (1,0).

pub fn tuple_variation_count(&self) -> TupleVariationCount

A packed field. The high 4 bits are flags, and the low 12 bits are the number of tuple variation tables for this glyph. The number of tuple variation tables can be any number between 1 and 4095.

pub fn data_offset(&self) -> Offset16

Offset from the start of the ‘cvar’ table to the serialized data.

pub fn data(&self) -> Result<FontData<'a>, ReadError>

Attempt to resolve data_offset.

pub fn tuple_variation_headers( &self, ) -> VarLenArray<'a, TupleVariationHeader<'a>>

Array of tuple variation headers.

pub fn version_byte_range(&self) -> Range<usize>

pub fn tuple_variation_count_byte_range(&self) -> Range<usize>

pub fn data_offset_byte_range(&self) -> Range<usize>

pub fn tuple_variation_headers_byte_range(&self) -> Range<usize>

Source

impl<'a> Cvar<'a>

pub fn variation_data( &self, axis_count: u16, ) -> Result<CvtVariationData<'a>, ReadError>

Returns the variation data containing the tuples and deltas for the control value table.

This table doesn’t contain an axis count field so this must be provided by the user and can be read from the fvar table.

pub fn deltas( &self, axis_count: u16, coords: &[F2Dot14], deltas: &mut [i32], ) -> Result<(), ReadError>

Computes the accumulated deltas for the given set of normalized coordinates and stores them in deltas.

The axis_count parameter expects the value from the fvar table.

The deltas slice should have a length greater than or equal to the number of values in the cvt table. The values are computed in 16.16 format.

fn raw_tuple_header_data(&self) -> FontData<'a>